==> vradi-entities-0.0.4-sources.jar: com/jurismarches/vradi/entities/StatusBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import org.sharengo.wikitty.BusinessEntityBean;

public class StatusBean extends BusinessEntityBean implements Status {

    private static final long serialVersionUID = -1476771946L;

    public StatusBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String Status$name;

     public int Status$value;

     public String Status$description;

     public boolean Status$modifiable;

 
    public void setName(String value) {
        Object oldValue = Status$name; 
        this.Status$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return Status$name;
    }


    public void setValue(int value) {
        Object oldValue = Status$value; 
        this.Status$value = value;
        propertyChange.firePropertyChange("value", oldValue, value);
    }

    public int getValue() {
        return Status$value;
    }


    public void setDescription(String value) {
        Object oldValue = Status$description; 
        this.Status$description = value;
        propertyChange.firePropertyChange("description", oldValue, value);
    }

    public String getDescription() {
        return Status$description;
    }


    public void setModifiable(boolean value) {
        Object oldValue = Status$modifiable; 
        this.Status$modifiable = value;
        propertyChange.firePropertyChange("modifiable", oldValue, value);
    }

    public boolean getModifiable() {
        return Status$modifiable;
    }


} //StatusBean

==> vradi-entities-0.0.5-sources.jar: com/jurismarches/vradi/entities/StatusBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import org.sharengo.wikitty.BusinessEntityBean;

public class StatusBean extends BusinessEntityBean implements Status {

    private static final long serialVersionUID = -1476771946L;

    public StatusBean() {
        super();
    }

    protected transient PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String Status$name;

    public int Status$value;

    public String Status$description;

    public boolean Status$modifiable;


    public void setName(String value) {
        Object oldValue = Status$name; 
        this.Status$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return Status$name;
    }


    public void setValue(int value) {
        Object oldValue = Status$value; 
        this.Status$value = value;
        propertyChange.firePropertyChange("value", oldValue, value);
    }

    public int getValue() {
        return Status$value;
    }


    public void setDescription(String value) {
        Object oldValue = Status$description; 
        this.Status$description = value;
        propertyChange.firePropertyChange("description", oldValue, value);
    }

    public String getDescription() {
        return Status$description;
    }


    public void setModifiable(boolean value) {
        Object oldValue = Status$modifiable; 
        this.Status$modifiable = value;
        propertyChange.firePropertyChange("modifiable", oldValue, value);
    }

    public boolean getModifiable() {
        return Status$modifiable;
    }


} //StatusBean
